@@ -1,8 +1,8 @@
 import sys
 import time
 
+from je_auto_control.utils.exception.exception_tags import linux_import_error
 from je_auto_control.utils.exception.exceptions import AutoControlException
-from je_auto_control.utils.exception.exception_tag import linux_import_error
 
 if sys.platform not in ["linux", "linux2"]:
     raise AutoControlException(linux_import_error)
@@ -20,7 +20,7 @@ def press_key(keycode: int) -> None:
         time.sleep(0.01)
         fake_input(display, X.KeyPress, keycode)
         display.sync()
-    except struct.error as error:
+    except Exception as error:
         print(repr(error), file=sys.stderr)
 
 
@@ -32,5 +32,5 @@ def release_key(keycode: int) -> None:
         time.sleep(0.01)
         fake_input(display, X.KeyRelease, keycode)
         display.sync()
-    except struct.error as error:
+    except Exception as error:
         print(repr(error), file=sys.stderr)
